@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
-   @project: HSPyLib
-   @package: hspylib.app.vault.src.main
+   @project: HSPyLib-Vault
+   @package: vault
       @file: __main__.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -61,7 +60,8 @@ class Main(TUIApplication):
             .argument('add', 'add a NEW UNIQUE vault entry') \
                 .add_parameter('name', 'the name of the vault entry which identifies it') \
                 .add_parameter('hint', 'applicable hints related to that vault entry') \
-                .add_parameter('password', 'the password of the entry. If not provided, it will be prompted', nargs='?') \
+                .add_parameter('password', 'the password of the entry. If not provided, it will be prompted',
+                               nargs='?') \
             .argument('upd', 'update an existing vault entry') \
                 .add_parameter('name', 'the name of the vault entry which identifies it') \
                 .add_parameter('hint', 'applicable hints related to that vault entry') \
